@@ -28,7 +28,8 @@ exclude_patterns = [
 pygments_style = 'sphinx'
 
 # Options for HTML output
-html_theme = 'default' if on_rtd else 'classic'
+html_theme = 'furo'
+html_title = 'Sybil'
 htmlhelp_basename = project+'doc'
 
 # Options for LaTeX output
