@@ -4,14 +4,16 @@ import os
 import re
 from functools import partial
 from os.path import split
+from pathlib import Path
 
 import pytest
+from py.path import local
 
 from sybil import Sybil, Region
 from sybil.document import Document
 from sybil.example import Example, SybilFailure
 
-from .helpers import sample_path
+from .helpers import sample_path, write_doctest
 
 
 @pytest.fixture()
@@ -19,14 +21,14 @@ def document():
     return Document('ABCDEFGH', '/the/path')
 
 
-class TestRegion(object):
+class TestRegion:
 
     def test_repr(self):
         region = Region(0, 1, 'parsed', 'evaluator')
         assert repr(region) == "<Region start=0 end=1 'evaluator'>"
 
 
-class TestExample(object):
+class TestExample:
 
     def test_repr(self, document):
         region = Region(0, 1, 'parsed', 'evaluator')
@@ -68,7 +70,7 @@ class TestExample(object):
         assert str(excinfo.value) == 'foo!'
 
 
-class TestDocument(object):
+class TestDocument:
 
     def test_add(self, document):
         region = Region(0, 1, None, None)
@@ -162,7 +164,7 @@ class TestDocument(object):
 
 
 def check(letter, parsed, namespace):
-    assert namespace == 42
+    assert namespace is None
     text, expected = parsed
     assert set(text) == {letter}
     actual = text.count(letter)
@@ -188,88 +190,42 @@ def parse_for_y(document):
                      partial(check, 'Y'))
 
 
-def parse_first_line(document):
-    line = document.text.split('\n', 1)[0]
-    yield Region(0, len(line), line, None)
+def evaluate_examples(examples):
+    return [e.region.evaluator(e.region.parsed, namespace=None)
+            for e in examples]
 
 
-class TestSybil(object):
-
-    def _evaluate_examples(self, examples, namespace):
-        return [e.region.evaluator(e.region.parsed, namespace)
-                for e in examples]
-
-    def _all_examples(self, sybil):
-        for document in sybil.all_documents():
-            for example in document:
-                yield example
+class TestSybil:
 
     def test_parse(self):
-        sybil = Sybil([parse_for_x, parse_for_y], '*')
-        document = sybil.parse(sample_path('sample1.txt'))
-        assert (self._evaluate_examples(document, 42) ==
+        sybil = Sybil([parse_for_x, parse_for_y])
+        document = sybil.parse(Path(sample_path('sample1.txt')))
+        assert (evaluate_examples(document) ==
                 ['X count was 4, as expected',
                  'Y count was 3, as expected'])
-
-    def test_all_paths(self):
-        sybil = Sybil([parse_first_line], '__init__.py')
-        assert ([e.region.parsed for e in self._all_examples(sybil)] ==
-                ['# believe it or not,'])
-
-    def test_all_paths_with_base_directory(self):
-        sybil = Sybil([parse_for_x, parse_for_y],
-                      path='./samples', pattern='*.txt')
-        assert (self._evaluate_examples(self._all_examples(sybil), 42) ==
-                ['X count was 4, as expected',
-                 'Y count was 3, as expected',
-                 'X count was 3 instead of 4',
+        document = sybil.parse(Path(sample_path('sample2.txt')))
+        assert (evaluate_examples(document) ==
+                ['X count was 3 instead of 4',
                  'Y count was 3, as expected'])
 
-    def test_explicit_encoding(self, tmp_path):
-        (tmp_path / 'encoded.txt').write_text(
-            u'X 1 check\n\xa3',
-            encoding='charmap'
-        )
-        sybil = Sybil([parse_for_x], path=str(tmp_path), pattern='*.txt',
-                      encoding='charmap')
-        assert (self._evaluate_examples(self._all_examples(sybil), 42) ==
+    def test_explicit_encoding(self, tmp_path: Path):
+        path = (tmp_path / 'encoded.txt')
+        path.write_text(u'X 1 check\n\xa3', encoding='charmap')
+        sybil = Sybil([parse_for_x], encoding='charmap')
+        document = sybil.parse(path)
+        assert (evaluate_examples(document) ==
                 ['X count was 1, as expected'])
 
+    def test_augment_document_mapping(self, tmpdir: local):
 
-class TestFiltering(object):
+        class TextDocument(Document):
+            pass
 
-    def check(self, tmp_path, sybil, expected):
-        assert expected == [d.path[len(str(tmp_path))+1:].split(os.sep)
-                            for d in sybil.all_documents()]
-
-    def test_excludes(self, tmp_path):
-        (tmp_path / 'foo.txt').write_text(u'')
-        (tmp_path / 'bar.txt').write_text(u'')
-        sybil = Sybil([], path=str(tmp_path), pattern='*.txt', excludes=['bar.txt'])
-        self.check(tmp_path, sybil, expected=[['foo.txt']])
-
-    def test_filenames(self, tmp_path):
-        (tmp_path / 'foo.txt').write_text(u'')
-        (tmp_path / 'bar.txt').write_text(u'')
-        (tmp_path / 'baz').mkdir()
-        (tmp_path / 'baz' / 'bar.txt').write_text(u'')
-        sybil = Sybil([], path=str(tmp_path), filenames=['bar.txt'])
-        self.check(tmp_path, sybil, expected=[['bar.txt'], ['baz', 'bar.txt']])
-
-    def test_glob_patterns(self, tmp_path):
-        (tmp_path / 'middle').mkdir()
-        interesting = (tmp_path / 'middle' / 'interesting')
-        interesting.mkdir()
-        boring = (tmp_path / 'middle' / 'boring')
-        boring.mkdir()
-        (interesting / 'foo.txt').write_text(u'')
-        (boring / 'bad1.txt').write_text(u'')
-        (tmp_path / 'bad2.txt').write_text(u'')
-        sybil = Sybil([],
-                      path=str(tmp_path),
-                      pattern='**middle/*.txt',
-                      excludes=['**/boring/*.txt'])
-        self.check(tmp_path, sybil, expected=[['middle', 'interesting', 'foo.txt']])
+        sybil = Sybil([], document_types={'.txt': TextDocument})
+        document = sybil.parse(write_doctest(tmpdir, 'test.txt'))
+        assert type(document) is TextDocument
+        document = sybil.parse(write_doctest(tmpdir, 'test.rst'))
+        assert type(document) is Document
 
 
 def check_into_namespace(example):
@@ -286,13 +242,18 @@ def parse(document):
 
 
 def test_namespace(capsys):
-    sybil = Sybil([parse],
-                  path='./samples', pattern='*.txt')
-    for document in sybil.all_documents():
+    sybil = Sybil([parse], path='./samples')
+    documents = [sybil.parse(p) for p in sorted(sybil.path.glob('sample*.txt'))]
+    actual = []
+    for document in documents:
         for example in document:
-            print(split(example.document.path)[-1], example.line)
+            print(split(example.path)[-1], example.line)
             example.evaluate()
-
+            actual.append((
+                split(example.path)[-1],
+                example.line,
+                document.namespace['parsed'].copy(),
+            ))
     out, _ = capsys.readouterr()
     assert out.split('\n') == [
         'sample1.txt 1',
